@@ -5,6 +5,7 @@ const extract = require("./extract")
 const utils = require("./utils")
 const splatSet = utils.splatSet
 const getSettings = require("./settings").getSettings
+const getFileMode = require("./getFileMode")
 
 const PREPARE_RULE_NAME = "__eslint-plugin-html-prepare"
 const LINTER_ISPATCHED_PROPERTY_NAME =
@@ -20,12 +21,17 @@ const LINTER_ISPATCHED_PROPERTY_NAME =
 // https://github.com/eslint/eslint/issues/3422
 // https://github.com/eslint/eslint/issues/4153
 
-const needle = path.join("lib", "linter.js")
+const needles = [
+  path.join("lib", "linter", "linter.js"), // ESLint 6+
+  path.join("lib", "linter.js"), // ESLint 5-
+]
 
 iterateESLintModules(patch)
 
 function getLinterFromModule(moduleExports) {
-  return moduleExports.Linter ? moduleExports.Linter : moduleExports
+  return moduleExports.Linter
+    ? moduleExports.Linter // ESLint 6+
+    : moduleExports // ESLint 5-
 }
 
 function getModuleFromRequire() {
@@ -33,7 +39,7 @@ function getModuleFromRequire() {
 }
 
 function getModuleFromCache(key) {
-  if (!key.endsWith(needle)) return
+  if (!needles.some((needle) => key.endsWith(needle))) return
 
   const module = require.cache[key]
   if (!module || !module.exports) return
@@ -77,7 +83,7 @@ function iterateESLintModules(fn) {
       eslintVersion = "n/a"
     }
 
-    const parentPaths = module =>
+    const parentPaths = (module) =>
       module ? [module.filename].concat(parentPaths(module.parent)) : []
 
     throw new Error(
@@ -103,30 +109,18 @@ In the report, please include *all* those informations:
   }
 }
 
-function getMode(pluginSettings, filenameOrOptions) {
-  const filename =
-    typeof filenameOrOptions === "object"
-      ? filenameOrOptions.filename
-      : filenameOrOptions
-  const extension = path.extname(filename || "")
-
-  if (pluginSettings.htmlExtensions.indexOf(extension) >= 0) {
-    return "html"
-  }
-  if (pluginSettings.xmlExtensions.indexOf(extension) >= 0) {
-    return "xml"
-  }
-}
-
 function patch(Linter) {
-  const verify = Linter.prototype.verify
+  const verifyMethodName = Linter.prototype._verifyWithoutProcessors
+    ? "_verifyWithoutProcessors" // ESLint 6+
+    : "verify" // ESLint 5-
+  const verify = Linter.prototype[verifyMethodName]
 
   // ignore if verify function is already been patched sometime before
   if (Linter[LINTER_ISPATCHED_PROPERTY_NAME] === true) {
     return
   }
   Linter[LINTER_ISPATCHED_PROPERTY_NAME] = true
-  Linter.prototype.verify = function(
+  Linter.prototype[verifyMethodName] = function (
     textOrSourceCode,
     config,
     filenameOrOptions,
@@ -137,7 +131,7 @@ function patch(Linter) {
     }
 
     const pluginSettings = getSettings(config.settings || {})
-    const mode = getMode(pluginSettings, filenameOrOptions)
+    const mode = getFileMode(pluginSettings, filenameOrOptions)
 
     if (!mode || typeof textOrSourceCode !== "string") {
       return verify.call(
@@ -159,7 +153,7 @@ function patch(Linter) {
 
     if (pluginSettings.reportBadIndent) {
       messages.push(
-        ...extractResult.badIndentationLines.map(line => ({
+        ...extractResult.badIndentationLines.map((line) => ({
           message: "Bad line indentation.",
           line,
           column: 1,
@@ -172,7 +166,7 @@ function patch(Linter) {
     // Save code parts parsed source code so we don't have to parse it twice
     const sourceCodes = new WeakMap()
     const verifyCodePart = (codePart, { prepare, ignoreRules } = {}) => {
-      this.defineRule(PREPARE_RULE_NAME, context => {
+      this.defineRule(PREPARE_RULE_NAME, (context) => {
         sourceCodes.set(codePart, context.getSourceCode())
         return {
           Program() {
@@ -242,10 +236,10 @@ function verifyWithSharedScopes(codeParts, verifyCodePart, parserOptions) {
         firstPassValues.push({
           codePart,
           exportedGlobals: globalScope.through.map(
-            node => node.identifier.name
+            (node) => node.identifier.name
           ),
           declaredGlobals: scopeForDeclaredGlobals.variables.map(
-            variable => variable.name
+            (variable) => variable.name
           ),
         })
       },
@@ -260,17 +254,17 @@ function verifyWithSharedScopes(codeParts, verifyCodePart, parserOptions) {
         const exportedGlobals = splatSet(
           firstPassValues
             .slice(i + 1)
-            .map(nextValues => nextValues.exportedGlobals)
+            .map((nextValues) => nextValues.exportedGlobals)
         )
         for (const name of exportedGlobals) context.markVariableAsUsed(name)
 
         const declaredGlobals = splatSet(
           firstPassValues
             .slice(0, i)
-            .map(previousValues => previousValues.declaredGlobals)
+            .map((previousValues) => previousValues.declaredGlobals)
         )
         const scope = context.getScope()
-        scope.through = scope.through.filter(variable => {
+        scope.through = scope.through.filter((variable) => {
           return !declaredGlobals.has(variable.identifier.name)
         })
       },
@@ -280,47 +274,62 @@ function verifyWithSharedScopes(codeParts, verifyCodePart, parserOptions) {
 
 function remapMessages(messages, hasBOM, codePart) {
   const newMessages = []
-  const bomOffset = hasBOM ? -1 : 0
 
   for (const message of messages) {
-    const location = codePart.originalLocation({
-      line: message.line,
-      // eslint-plugin-eslint-comments is raising message with column=0 to bypass ESLint ignore
-      // comments. Since messages are already ignored at this time, just reset the column to a valid
-      // number. See https://github.com/BenoitZugmeyer/eslint-plugin-html/issues/70
-      column: message.column || 1,
-    })
-
-    // Ignore messages if they were in transformed code
-    if (location) {
-      Object.assign(message, location)
-      message.source = codePart.getOriginalLine(location.line)
-
-      // Map fix range
-      if (message.fix && message.fix.range) {
-        message.fix.range = [
-          codePart.originalIndex(message.fix.range[0]) + bomOffset,
-          // The range end is exclusive, meaning it should replace all characters  with indexes from
-          // start to end - 1. We have to get the original index of the last targeted character.
-          codePart.originalIndex(message.fix.range[1] - 1) + 1 + bomOffset,
-        ]
-      }
-
-      // Map end location
-      if (message.endLine && message.endColumn) {
-        const endLocation = codePart.originalLocation({
-          line: message.endLine,
-          column: message.endColumn,
-        })
-        if (endLocation) {
-          message.endLine = endLocation.line
-          message.endColumn = endLocation.column
-        }
-      }
-
+    if (remapMessage(message, hasBOM, codePart)) {
       newMessages.push(message)
     }
   }
 
   return newMessages
 }
+
+function remapMessage(message, hasBOM, codePart) {
+  if (!message.line || !message.column) {
+    // Some messages apply to the whole file instead of a particular code location. In particular:
+    // * @typescript-eslint/parser may send messages with no line/column
+    // * eslint-plugin-eslint-comments send messages with column=0 to bypass ESLint ignore comments.
+    //   See https://github.com/BenoitZugmeyer/eslint-plugin-html/issues/70
+    // For now, just include them in the output. In the future, we should make sure those messages
+    // are not print twice.
+    return true
+  }
+
+  const location = codePart.originalLocation({
+    line: message.line,
+    column: message.column,
+  })
+
+  // Ignore messages if they were in transformed code
+  if (!location) {
+    return false
+  }
+
+  Object.assign(message, location)
+  message.source = codePart.getOriginalLine(location.line)
+
+  // Map fix range
+  if (message.fix && message.fix.range) {
+    const bomOffset = hasBOM ? -1 : 0
+    message.fix.range = [
+      codePart.originalIndex(message.fix.range[0]) + bomOffset,
+      // The range end is exclusive, meaning it should replace all characters  with indexes from
+      // start to end - 1. We have to get the original index of the last targeted character.
+      codePart.originalIndex(message.fix.range[1] - 1) + 1 + bomOffset,
+    ]
+  }
+
+  // Map end location
+  if (message.endLine && message.endColumn) {
+    const endLocation = codePart.originalLocation({
+      line: message.endLine,
+      column: message.endColumn,
+    })
+    if (endLocation) {
+      message.endLine = endLocation.line
+      message.endColumn = endLocation.column
+    }
+  }
+
+  return true
+}
